Documentation
¶
Index ¶
Constants ¶
const ( // Poll is a poll interval for VA Poll = 2 * time.Second // Timeout is a timeout for Va operations Timeout = 1800 * time.Second )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// KubeClient *core.KubeClient
Interface v12.VolumeAttachmentInterface
Namespace string
Timeout int
CustomTimeout time.Duration
}
Client is a VA client for managing VolumeAttachments
func (*Client) DeleteVaBasedOnPVName ¶
DeleteVaBasedOnPVName deletes the VA associated with passed PV
func (*Client) WaitUntilNoneLeft ¶
WaitUntilNoneLeft waits for all volume attachments to be deleted in a namespace
Click to show internal directories.
Click to hide internal directories.